@@ -1,64 +1,12 @@
 package CodeGen::Cpppp;
-$CodeGen::Cpppp::VERSION = '0.001_01'; # TRIAL
-$CodeGen::Cpppp::VERSION = '0.00101';
 use strict;
 use warnings;
 use Carp;
 
-# VERSION
+our $VERSION = '0.001_02'; # TRIAL VERSION
 # ABSTRACT: The C Perl-Powered Pre-Processor
 
-=head1 SYNOPSIS
 
-I<Does that mean it's more powerful?  ...Is it more powerful?>
-
-I<Well, it's one layer of abstraction higher, isn't it?  It's not C<m4>.  You see, most
-blokes gonna be templating with C<cpp> or C<m4>, you're on C<m4> here all the way up,
-all the way up, Where can you go from there? Where?  Nowhere!  Exactly.>
-
-I<What we do is if we need that extra, push, over the cliff, you know what we do?>
-
-I<C<perl>, exactly. These go to C<perl>.>
-
-  #! /usr/bin/env cpppp
-  ## for (my $bits= 8; $bits <= 32; $bits <<= 1) {
-  struct tree_node_$bits {
-    uint${bits}_t left:  ${{$bits-1}},
-                  color: 1,
-                  right: ${{$bits-1}};
-  }
-  ## }
-
-Output:
-
-  struct tree_node_8 {
-    uint8_t left:  7,
-            right: 7,
-            color: 1;
-  }
-  struct tree_node_16 {
-    uint16_t left:  15,
-             right: 15,
-             color: 1;
-  }
-  struct tree_node_32 {
-    uint32_t left:  31,
-             right: 31,
-             color: 1;
-  }
-
-=head1 DESCRIPTION
-
-B<WARNING: this API is complete and totally unstable>.
-
-If you have an interest in this, contact me, because I could use help brainstorming ideas
-about how to accommodate the most possibilities, here.
-
-=head1 CONSTRUCTOR
-
-Bare-bones for now, it accepts whatever hash values you hand to it.
-
-=cut
 
 sub new {
    my ($class, %attrs)= @_;
@@ -66,17 +14,6 @@ sub new {
    bless \%attrs, $class;
 }
 
-=head1 METHODS
-
-=head2 compile_template
-
-  $cpppp->compile_template($input_fh, $filename);
-  $cpppp->compile_template(\$scalar_tpl, $filename, $line_offset);
-
-This reads the input file handle (or scalar-ref) and builds a perl subroutine out of it, then
-evals that subroutine so it is ready to run (and spits out any compile errors in the template).
-
-=cut
 
 sub compile_template {
    my ($self, $in, $filename, $line)= @_;
@@ -93,15 +30,6 @@ sub compile_template {
    return $self;
 }
 
-=head1 METHODS
-
-=head2 render
-
-  $cpppp->render();
-
-Execute the template previously compiled.  Passing arguments to this template is a TODO item.
-
-=cut
 
 sub render {
    my $self= shift;
@@ -331,10 +259,8 @@ sub _render_code_block {
          my $oldcol= $group->[$i] - $linestart;
          my $diff= $newcol - $oldcol;
          if ($diff < 0) {
-            print "subtract $diff characters at $linestart+$newcol\n";
             substr($text, $linestart + $newcol, -$diff, '');
          } elsif($diff > 0) {
-            print "insert $diff spaces at $linestart+$oldcol\n";
             substr($text, $linestart + $oldcol, 0, ' 'x$diff);
          }
          # update all positions beyond this one
@@ -350,6 +276,121 @@ sub _render_code_block {
 
 1;
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+CodeGen::Cpppp - The C Perl-Powered Pre-Processor
+
+=head1 VERSION
+
+version 0.001_02
+
+=head1 SYNOPSIS
+
+I<Does that mean it's more powerful?  ...Is it more powerful?>
+
+I<Well, it's one layer of abstraction higher, isn't it?  It's not C<m4>.  You see, most
+blokes gonna be templating with C<cpp> or C<m4>, you're on C<m4> here all the way up,
+all the way up, Where can you go from there? Where?>
+
+I<Nowhere!  Exactly.>
+
+I<What we do is if we need that extra, push, over the cliff, you know what we do?>
+
+I<C<perl>, exactly.>
+
+I<These go to C<perl>.>
+
+B<Input:>
+
+  #! /usr/bin/env cpppp
+  ## for (my $bits= 8; $bits <= 32; $bits <<= 1) {
+  struct tree_node_$bits {
+    uint${bits}_t  left:  ${{$bits-1}},
+                   color: 1,
+                   right: ${{$bits-1}};
+  };
+  ## }
+
+B<Output:>
+
+  struct tree_node_8 {
+    uint8_t left:  7,
+            right: 7,
+            color: 1;
+  };
+  struct tree_node_16 {
+    uint16_t left:  15,
+             right: 15,
+             color: 1;
+  };
+  struct tree_node_32 {
+    uint32_t left:  31,
+             right: 31,
+             color: 1;
+  };
+
+=head1 DESCRIPTION
+
+B<WARNING: this API is complete and totally unstable>.
+
+This module is a preprocessor for C, 
+
+If you have an interest in this, contact me, because I could use help brainstorming ideas
+about how to accommodate the most possibilities, here.
+
+Possibilities:
+
+=over
+
+=item *
+
+Scan existing headers to discover available macros, structs, and functions on the host.
+
+=item *
+
+Pass a list of headers through the real cpp and analyze the macro output.
+
+=item *
+
+Shell out to a compiler to find 'sizeof' information for structs.
+
+=head1 CONSTRUCTOR
+
+Bare-bones for now, it accepts whatever hash values you hand to it.
+
+=head1 METHODS
+
+=head2 compile_template
+
+  $cpppp->compile_template($input_fh, $filename);
+  $cpppp->compile_template(\$scalar_tpl, $filename, $line_offset);
+
+This reads the input file handle (or scalar-ref) and builds a perl subroutine out of it, then
+evals that subroutine so it is ready to run (and spits out any compile errors in the template).
+
+=head2 render
+
+  $cpppp->render();
+
+Execute the template previously compiled.  Passing arguments to this template is a TODO item.
+
+=head1 AUTHOR
+
+Michael Conrad <mike@nrdvana.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Michael Conrad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
 __END__
 sub patch_header($self, $fname, $patch_markers=undef) {
    $patch_markers //= "GENERATED ".uc($self->namespace)." HEADERS";
